ItemComparator<T> class

Provides values used in the PaginatedComparator.itemBuilder method with each iteration.

Constructors

ItemComparator({required ItemData<T> previousItem, required ItemData<T> currentItem, required ItemData<T> nextItem, required bool isFirstItem, required bool isLastItem})
const

Properties

current → T
no setter
currentItem ItemData<T>
final
hashCode int
The hash code for this object.
no setterinherited
isFirstItem bool
final
isLastItem bool
final
next → T
no setter
nextItem ItemData<T>
final
previous → T
no setter
previousItem ItemData<T>
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited