emptyWidget property

Widget? emptyWidget
final

Optional replacement for the empty widget displayed when we've finished loading the first chunk and there are still no items

Implementation

final Widget? emptyWidget;