itemErrorWidgetBuilder property
Optional replacement for the error widget displayed when calling the paginatedItemBuilder fails
Defaults to use the DefaultErrorCard
Implementation
final ErrorWidgetBuilder? itemErrorWidgetBuilder;
Optional replacement for the error widget displayed when calling the paginatedItemBuilder fails
Defaults to use the DefaultErrorCard
final ErrorWidgetBuilder? itemErrorWidgetBuilder;