listBuilder property
The function used to generate the widget shown when items exist in the cache.
Commonly a ListView.builder Widget will be returned as you can directly
replace ListViews required itemBuilder argument with the provided
paginatedItemBuilder parameter.
Param
The AnimatableIndexedWidgetBuilder is the paginated item builder provided by this widget. Use it as a direct replacement for any regular or animated itemBuilder.
Implementation
final EnclosingWidgetBuilder listBuilder;