listStartChangeStream property

Stream<PaginatedSnapshot<DataType>> listStartChangeStream
final

The stream listened to once the initial page load happens.

When items are added to this stream, they will be added to the beginning of the cache and onItemReceived will be called with a zero index.

Implementation

final Stream<PaginatedSnapshot<DataType>> listStartChangeStream;