pageErrorWidgetBuilder property
Optional replacement for the error widget displayed when getting the next chunk fails
Defaults to use the DefaultErrorCard
Implementation
final ErrorWidgetBuilder? pageErrorWidgetBuilder;
Optional replacement for the error widget displayed when getting the next chunk fails
Defaults to use the DefaultErrorCard
final ErrorWidgetBuilder? pageErrorWidgetBuilder;