pageLoadingWidget property
Optional replacement for the loading widget displayed before the first chunk is loaded.
Defaults to use DefaultPageLoadingView
Implementation
final Widget? pageLoadingWidget;
Optional replacement for the loading widget displayed before the first chunk is loaded.
Defaults to use DefaultPageLoadingView
final Widget? pageLoadingWidget;