rebuildListWhenChunkIsCached property
Whether to recreate the Widget provided in the listBuilder when items from a new chunk is added to the in-memory cache
By default, the list created by the listBuilder is only ever built once on initialization. Every time the list is re-built, all items need to be recreated using the item builder. Therefore, it is recommended to use a list that allows you to add in the items as they come in through the onItemReceived callback.
However, when using a standard ListView, there is no mechanism to insert
items into the list without rebuilding the entire list. Because of this,
you can set this value to true and the list will re-initialize with all
of the cached items retrieved so far.
It's recommended to use a AnimatedList to insert and removes items from
the state using a GlobalKey or the static of method (see
AnimatedList's doc comments for details).
Implementation
final bool rebuildListWhenChunkIsCached;