rebuildListWhenStreamHasChanges property
Whether to recreate the the Widget provided in the listBuilder after a change comes through on the listStartChangeStream.
Implementation
final bool rebuildListWhenStreamHasChanges;
Whether to recreate the the Widget provided in the listBuilder after a change comes through on the listStartChangeStream.
final bool rebuildListWhenStreamHasChanges;