shouldShowItemLoader property

bool shouldShowItemLoader
final

Whether to replace the last item in the list with a loading Widget when a new chunk is being retrieved.

Defaults to true

See: itemLoadingWidget to use a custom Widget as the loader

Implementation

final bool shouldShowItemLoader;