itemBuilder property

ConvertedWidgetBuilder<DataType> itemBuilder
final

The item builder is the same callback used with ListView.builder with one exception. Normally you receive an index, whereas with this itemBuilder you receive your converted item at that index instead.

This item is retrieved from the in-memory cache located in the PaginatedBuilderState.cachedItems property of the State class.

Implementation

final ConvertedWidgetBuilder<DataType> itemBuilder;