PaginatedComparatorState<DataType, CursorType> class final

Inheritance

Constructors

PaginatedComparatorState()

Properties

cachedItems List<DataType>
no setterinherited
cacheIndex int
no setterinherited
cacheLength int
no setterinherited
chunksRequested int
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
dataSourceChangesSub StreamSubscription<PaginatedSnapshot<DataType>>?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
lastCachedChunkStartingIndex int
no setterinherited
lastRequestedChunk Chunk<DataType, CursorType>
getter/setter pairinherited
limit int
no setterinherited
loading bool
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
nextAvailableChunk Chunk<DataType, CursorType>
getter/setter pairinherited
pageErrorWidget Widget?
getter/setter pairinherited
requestThresholdIndex int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget PaginatedComparator<DataType, CursorType>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
conditionalPrint(String message) → void
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant PaginatedComparator<DataType, CursorType> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getChunkIfInLastChunkAndPastThreshold(int index) Future<void>
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paginatedItemBuilder(BuildContext context, int index, [Animation<double>? animation]) Widget
override
paginatedItemBuilderWithEndLoader(BuildContext context, int index, [Animation<double>? animation]) Widget
inherited
paginatorBuilder(CursorSelector<DataType, CursorType> cursorSelector, DataChunker<DataType, CursorType> dataChunker) Paginator<DataType, CursorType>
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
withinRange(int index) int
Contains the available index to be within bounds

Operators

operator ==(Object other) bool
The equality operator.
inherited