PaginatedSnapshot<T> class base

Constructors

PaginatedSnapshot({required T data, required SnapshotState state, dynamic uniqueIdFinder(T)?})
const

Properties

data → T
The data of the snapshot
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SnapshotState
The state of the snapshot
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uniqueIdFinder → dynamic Function(T)?
The function to find the unique ID of the data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited