Chunker<DataType, CursorType> class
Constructors
-
Chunker({required CursorType cursorSelector(DataType), required DataChunker<DataType, CursorType> dataChunker})
-
Properties
-
cursorSelector
→ CursorType Function(DataType)
-
Used to select the value to passed into the dataChunker the next time
it's called.
final
-
dataChunker
→ DataChunker<DataType, CursorType>
-
Called to retrieve the next
n number of items from your data source.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getNext(Chunk<DataType, CursorType>? chunk)
→ Future<Chunk<DataType, CursorType>>
-
Retrieve the next chunk of data
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited