cursorSelector property
Used to select the value to passed into the dataChunker the next time it's called.
The cursor will come from the last item in the data returned by the
dataChunker. The cursor should be used to skip any records previously
retrieved before getting the next n records. n being the number of
records specified by the limit provided to the dataChunker callback.
Implementation
final CursorSelector<DataType, CursorType>? cursorSelector;