dataChunker property
Called to retrieve the next n number of items from your data source.
Use the provided cursor and limit to skip and get the next 'n' number
of items. The cursor will be the identifier selected using the
cursorSelector from the last time the getNext method was called.
If the cursor is null, this is the first time the method is being run
for this data source.
The limit is the maximum amount of items the method expects to receive
when being invoked.
Warning: To avoid duplicate items, ensure you're getting the
limit number of items AFTER the cursor.
Implementation
final DataChunker<DataType, CursorType> dataChunker;