emptyWidget property
Optional replacement for the empty widget displayed when we've finished loading the first chunk and there are still no items
Implementation
final Widget? emptyWidget;
Optional replacement for the empty widget displayed when we've finished loading the first chunk and there are still no items
final Widget? emptyWidget;