shouldAutoLoadNextChunk property
Whether to automatically load the next chunk of data when the threshold is met and more are available
Defaults to true
The PaginatedBaseState.getChunkIfInLastChunkAndPastThreshold method will
need to be manually invoked from your State Widget if this is set to
false.
See PaginatedBuilder for an example of how to extend this class correctly
Implementation
final bool shouldAutoLoadNextChunk;