thresholdPercent property
How far the user should be able to scroll into the last chunk before a new chunk is requested.
This value should be 0.0 exclusive to 1.0 inclusive.
Implementation
final double thresholdPercent;
How far the user should be able to scroll into the last chunk before a new chunk is requested.
This value should be 0.0 exclusive to 1.0 inclusive.
final double thresholdPercent;