itemBuilder property
The item builder is the same callback used with ListView.builder with one exception. Normally you receive an index, whereas with this itemBuilder you receive converted items instead of an index. The converted items are the previous item, the current item, and the next item.
Scenarios
First Item
previous == current
Last Item
current == next
Only 1 Item Available
previous == current == next
Items are retrieved from the in-memory cache located in the PaginatedComparatorState.cachedItems property of the State class.
Implementation
final ComparableWidgetBuilder<DataType> itemBuilder;